@@ -11,8 +11,6 @@
 #include <QTimer>
 #include <QDebug>
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-
 struct DelayedRequest {
     QUrl m_delayedURL;
     KParts::OpenUrlArguments m_delayedArgs;
@@ -76,6 +74,4 @@ void BrowserExtension::slotEmitOpenUrlRequestDelayed()
     Q_EMIT browserOpenUrlRequestDelayed(req.m_delayedURL, req.m_delayedArgs, req.m_delayedBrowserArgs);
 }
 
-#endif
-
 #include "moc_browserextension.cpp"
