@@ -23,12 +23,12 @@
 #include <kparts/mainwindow.h>
 #include <KParts/PartActivateEvent>
 #include <kservice.h>
+#include <KParts/NavigationExtension>
 
 #include "konqcombo.h"
 #include "konqframe.h"
 #include "konqframecontainer.h"
 #include "konqopenurlrequest.h"
-#include "kf5compat.h" //For NavigationExtension
 #include "configdialog.h"
 #include "windowargs.h"
 
@@ -359,6 +359,16 @@ public:
 
     QList<QAction*> toggleViewActions() const;
 
+    /**
+     * @brief Utility function which adjusts the KonqSettings::newTabInFront setting according to whether the user is pressing the `shift` key
+     *
+     * Since the `shift` key reverses the value of the KonqSettings::newTabInFront, when `shift` is pressed, this function returns the opposite
+     * of the option.
+     *
+     * @return `KonqSettings::newTabInFront()` if the user isn't pressing the `shift` key and `!KonqSettings::newTabInFront()` otherwise
+     */
+    static bool newTabInFront(Qt::KeyboardModifiers mods);
+
 Q_SIGNALS:
     void viewAdded(KonqView *view);
     void viewRemoved(KonqView *view);
@@ -380,13 +390,8 @@ public Q_SLOTS:
 
     void slotCtrlTabPressed();
 
-#if QT_VERSION_MAJOR < 6
-    void slotPopupMenu(const QPoint &global, const KFileItemList &items, const KParts::OpenUrlArguments &args, const BrowserArguments &browserArgs, KParts::NavigationExtension::PopupFlags flags, const KParts::NavigationExtension::ActionGroupMap &);
-    void slotPopupMenu(const QPoint &global, const QUrl &url, mode_t mode, const KParts::OpenUrlArguments &args, const BrowserArguments &browserArgs, KParts::NavigationExtension::PopupFlags f, const KParts::NavigationExtension::ActionGroupMap &);
-#else
     void slotPopupMenu(const QPoint &global, const KFileItemList &items, const KParts::OpenUrlArguments &args, const BrowserArguments &browserArgs, KParts::NavigationExtension::PopupFlags flags, const KParts::NavigationExtension::ActionGroupMap &, KonqView*);
     void slotPopupMenu(const QPoint &global, const QUrl &url, mode_t mode, const KParts::OpenUrlArguments &args, const BrowserArguments &browserArgs, KParts::NavigationExtension::PopupFlags f, const KParts::NavigationExtension::ActionGroupMap &, KonqView*);
-#endif
 
     void slotOpenURLRequest(const QUrl &url, KonqOpenURLRequest &req);
 
@@ -750,7 +755,6 @@ private: // members
 
     KBookmarkMenu *m_pBookmarkMenu;
     KonqExtendedBookmarkOwner *m_pBookmarksOwner;
-    KActionCollection *m_bookmarksActionCollection;
     bool m_bookmarkBarInitialized;
 
     KonqViewManager *m_pViewManager;
