@@ -16,11 +16,7 @@
 #include <KStartupInfo>
 #include <QTimer>
 
-#if QT_VERSION_MAJOR < 6
-#include <QX11Info>
-#else
 #include <QtGui/private/qtx11extras_p.h>
-#endif
 
 #include <KWindowSystem>
 
