@@ -11,7 +11,8 @@
 
 #include <QStringList>
 
-#include "kf5compat.h" //For NavigationExtension
+#include <KParts/NavigationExtension>
+
 #include "browserarguments.h"
 
 namespace KParts {
@@ -104,6 +105,7 @@ struct KONQ_TESTS_EXPORT KonqOpenURLRequest {
      * This is ignored if #letPartPerformDownload is `false`.
      */
     qint32 downloadId = -1;
+    bool forceOpen = false; ///< Whether the URL should be opened in an external application, regardless of settings
 
     static KonqOpenURLRequest null;
 };
