@@ -30,14 +30,18 @@ QString SpellCheckerManager::dictionaryDir()
     static const char *varName = "QTWEBENGINE_DICTIONARIES_PATH";
     static QString s_dir;
     if (s_dir.isNull()) {
-        if (!qEnvironmentVariableIsEmpty(varName)) {
+        if (qEnvironmentVariableIsSet(varName)) {
             s_dir = qEnvironmentVariable(varName);
         } else {
+#ifdef WEBENGINEPART_OWN_DICTIONARY_DIR
+            s_dir = QString(WEBENGINEPART_OWN_DICTIONARY_DIR);
+#else
             QLatin1String suffix("/qtwebengine_dictionaries");
             s_dir = QApplication::applicationDirPath() + suffix;
             if (!QDir(s_dir).exists()) {
                 s_dir = QLibraryInfo::location(QLibraryInfo::DataPath) + suffix;
             }
+#endif
         }
     }
     return s_dir;
